@@ -4,7 +4,7 @@ use warnings; use strict;
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use parent 'Elive::DAO::_Base';
 
@@ -1217,7 +1217,7 @@ sub live_entity {
 
     my $user_ref = $live_entities->{'http://test.org/User/1234567890'};
 
-Returns a reference to an object in the Elive::Entity cache. 
+Returns a reference to the Elive::Entity cache. 
 
 =cut
 
@@ -1573,9 +1573,13 @@ Abstract method to revert an entity to its last constructed value.
 
 =cut
 
+our $REVERTING;
+
 sub revert {
     my ($self, @props) = @_;
 
+    local( $REVERTING ) = 1;
+
     my $db_data = $self->_db_data
 	or die "object doesn't have db-data!? - can't cope";
 
@@ -1659,7 +1663,9 @@ sub DEMOLISH {
 	if ($self->debug||0) >= 5;
 
     if (my $db_data = $self->_db_data) {
-	if ((my @changed = $self->is_changed) && ! $self->_deleted) {
+	if (!$REVERTING
+	    && (my @changed = $self->is_changed)
+	    && ! $self->_deleted) {
 	    my $self_string = Elive::Util::string($self);
 	    Carp::carp("$class $self_string destroyed without saving or reverting changes to: "
 		 . join(', ', @changed));
